@@ -7,7 +7,7 @@ import functools, warnings, inspect
 
 log = logging.getLogger("GremlinAPI.client")
 
-_version = "0.12.2"
+_version = "0.13.1"
 
 
 def get_version():
@@ -17,10 +17,43 @@ def get_version():
 string_types = (type(b""), type(""), type(f""))
 
 
+def experimental(func):
+    """
+    This is a decorator that will be used on in-progress or
+    otherwise incomplete functions and objects.
+    """
+    if inspect.isclass(func) or inspect.isfunction(func):
+
+        @functools.wraps(func)
+        def new_func(*args, **kwargs):
+            message = "Call to experimental function `{}` ** Please proceed with caution **".format(
+                func.__name__
+            )
+            warnings.warn(message)
+            return func(*args, **kwargs)
+
+        return new_func
+
+    elif isinstance(func, string_types):
+
+        def decorator(func1):
+            @functools.wraps(func1)
+            def new_func1(*args, **kwargs):
+                message = "Call to experimental function `{}` ** %s **" % func
+                warnings.warn(message)
+                return func1(*args, **kwargs)
+
+            return new_func1
+
+        return decorator
+
+
 def deprecated(reason):
-    """This is a decorator which can be used to mark functions
+    """
+    This is a decorator which can be used to mark functions
     as deprecated. It will result in a warning being emitted
-    when the function is used."""
+    when the function is used.
+    """
 
     if inspect.isclass(reason) or inspect.isfunction(reason):
 
